@@ -8,9 +8,14 @@ class NepseException(Exception):
 
 class NotFound(NepseException):
     def __str__(self) -> str:
-        return "The Company name Provided was not found !"
+        return "The data provided was not found !"
 
 
 class APIError(NepseException):
     def __str__(self) -> str:
         return "The data couldn't be fetched from the NEPSE API for this"
+
+
+class CompanyNotFound(NotFound):
+    def __str__(self) -> str:
+        return "The provided company was not found !"
